@@ -19,7 +19,7 @@ limitations under the License.
 @author: Diego Torres Milano
 """
 
-__version__ = '1.0.2'
+__version__ = '1.0.4'
 
 import argparse as argparse
 import re
@@ -196,8 +196,8 @@ VIADUC_SCRIPT = """
         return a;
     }
     
-    function print(str) {
-        pywebview.api.print(str);
+    function _print(...args) {
+        pywebview.api.print(args);
     }
 </script>
 """
@@ -350,8 +350,8 @@ class Viaduc:
                 m[v['id']] = v['val']
             return m
 
-        def print(self, _str):
-            print(_str)
+        def print(self, *args):
+            print(args)
 
     class Presentation:
         width = 800
@@ -388,8 +388,8 @@ class Viaduc:
 
         # parse args
         arg_parser = argparse.ArgumentParser(description='Viaduc: simplest python GUI.')
-        arg_parser.add_argument('-x', '--debug', action='store_true', default=False)
-        arg_parser.add_argument('--frameless', action='store_true', default=False)
+        arg_parser.add_argument('-x', '--debug', action='store_true', default=False, help='enable debug tools')
+        arg_parser.add_argument('--frameless', action='store_true', default=False, help='create a frameless window')
         parsed_args = arg_parser.parse_args(args[1:])
         self.debug = parsed_args.debug
         self.frameless = parsed_args.frameless
@@ -434,6 +434,20 @@ class Viaduc:
     def on_top(self, value):
         self.window.on_top = value
 
+    @staticmethod
+    def done():
+        return {
+            'action': 'DONE'
+        }
+
+    @staticmethod
+    def callback(f: str, params: dict):
+        return {
+            'action': 'CALLBACK',
+            'function': f,
+            'params': params
+        }
+
 
 if __name__ == '__main__':
     Viaduc()
